==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/CustomContainerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.CustomContainerArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Custom container payload
 * @property args Arguments to the entrypoint. The docker image's CMD is used if this is not provided.
 * @property command Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided.
 * @property containerImage Container image of the custom container. This should be in the form of <repository>:<tag> without the server name of the registry
 * @property imageRegistryCredential Credential of the image registry
 * @property languageFramework Language framework of the container image uploaded
 * @property server The name of the registry that contains the container image
 */
public data class CustomContainerArgs(
    public val args: Output<List<String>>? = null,
    public val command: Output<List<String>>? = null,
    public val containerImage: Output<String>? = null,
    public val imageRegistryCredential: Output<ImageRegistryCredentialArgs>? = null,
    public val languageFramework: Output<String>? = null,
    public val server: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.CustomContainerArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.inputs.CustomContainerArgs =
        com.pulumi.azurenative.appplatform.inputs.CustomContainerArgs.builder()
            .args(args?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .command(command?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .containerImage(containerImage?.applyValue({ args0 -> args0 }))
            .imageRegistryCredential(
                imageRegistryCredential?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .languageFramework(languageFramework?.applyValue({ args0 -> args0 }))
            .server(server?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CustomContainerArgs].
 */
@PulumiTagMarker
public class CustomContainerArgsBuilder internal constructor() {
    private var args: Output<List<String>>? = null

    private var command: Output<List<String>>? = null

    private var containerImage: Output<String>? = null

    private var imageRegistryCredential: Output<ImageRegistryCredentialArgs>? = null

    private var languageFramework: Output<String>? = null

    private var server: Output<String>? = null

    /**
     * @param value Arguments to the entrypoint. The docker image's CMD is used if this is not provided.
     */
    @JvmName("wqndcbjckqfcknvp")
    public suspend fun args(`value`: Output<List<String>>) {
        this.args = value
    }

    @JvmName("pmpbmlhbyugpyhst")
    public suspend fun args(vararg values: Output<String>) {
        this.args = Output.all(values.asList())
    }

    /**
     * @param values Arguments to the entrypoint. The docker image's CMD is used if this is not provided.
     */
    @JvmName("dyduslvsbsfohadr")
    public suspend fun args(values: List<Output<String>>) {
        this.args = Output.all(values)
    }

    /**
     * @param value Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided.
     */
    @JvmName("xmkossgtvsnmcvrp")
    public suspend fun command(`value`: Output<List<String>>) {
        this.command = value
    }

    @JvmName("xnkdgfigyssbihuy")
    public suspend fun command(vararg values: Output<String>) {
        this.command = Output.all(values.asList())
    }

    /**
     * @param values Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided.
     */
    @JvmName("wctvsqlmvfysdfbi")
    public suspend fun command(values: List<Output<String>>) {
        this.command = Output.all(values)
    }

    /**
     * @param value Container image of the custom container. This should be in the form of <repository>:<tag> without the server name of the registry
     */
    @JvmName("piismidyvxncyhis")
    public suspend fun containerImage(`value`: Output<String>) {
        this.containerImage = value
    }

    /**
     * @param value Credential of the image registry
     */
    @JvmName("yvydmsrrdmqyinaa")
    public suspend fun imageRegistryCredential(`value`: Output<ImageRegistryCredentialArgs>) {
        this.imageRegistryCredential = value
    }

    /**
     * @param value Language framework of the container image uploaded
     */
    @JvmName("sftpqfyhfjasouur")
    public suspend fun languageFramework(`value`: Output<String>) {
        this.languageFramework = value
    }

    /**
     * @param value The name of the registry that contains the container image
     */
    @JvmName("jsdsiuysbdibfbjs")
    public suspend fun server(`value`: Output<String>) {
        this.server = value
    }

    /**
     * @param value Arguments to the entrypoint. The docker image's CMD is used if this is not provided.
     */
    @JvmName("dkmtnbhhwdbabreh")
    public suspend fun args(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.args = mapped
    }

    /**
     * @param values Arguments to the entrypoint. The docker image's CMD is used if this is not provided.
     */
    @JvmName("dkuqclkcdvcikety")
    public suspend fun args(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.args = mapped
    }

    /**
     * @param value Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided.
     */
    @JvmName("pjkxwyppitfyibuj")
    public suspend fun command(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.command = mapped
    }

    /**
     * @param values Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided.
     */
    @JvmName("nuwmrcirqdfewsrb")
    public suspend fun command(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.command = mapped
    }

    /**
     * @param value Container image of the custom container. This should be in the form of <repository>:<tag> without the server name of the registry
     */
    @JvmName("obauheiaomemasyh")
    public suspend fun containerImage(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerImage = mapped
    }

    /**
     * @param value Credential of the image registry
     */
    @JvmName("udfmrtsxcqbftpbx")
    public suspend fun imageRegistryCredential(`value`: ImageRegistryCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageRegistryCredential = mapped
    }

    /**
     * @param argument Credential of the image registry
     */
    @JvmName("kkllodpaliepwqem")
    public suspend
    fun imageRegistryCredential(argument: suspend ImageRegistryCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = ImageRegistryCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.imageRegistryCredential = mapped
    }

    /**
     * @param value Language framework of the container image uploaded
     */
    @JvmName("bkktmegrdumhwwrq")
    public suspend fun languageFramework(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.languageFramework = mapped
    }

    /**
     * @param value The name of the registry that contains the container image
     */
    @JvmName("idoqimrgdxwphtlo")
    public suspend fun server(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.server = mapped
    }

    internal fun build(): CustomContainerArgs = CustomContainerArgs(
        args = args,
        command = command,
        containerImage = containerImage,
        imageRegistryCredential = imageRegistryCredential,
        languageFramework = languageFramework,
        server = server,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/CustomContainerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.CustomContainerArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Custom container payload
 * @property args Arguments to the entrypoint. The docker image's CMD is used if this is not provided.
 * @property command Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided.
 * @property containerImage Container image of the custom container. This should be in the form of <repository>:<tag> without the server name of the registry
 * @property imageRegistryCredential Credential of the image registry
 * @property languageFramework Language framework of the container image uploaded
 * @property server The name of the registry that contains the container image
 */
public data class CustomContainerArgs(
    public val args: Output<List<String>>? = null,
    public val command: Output<List<String>>? = null,
    public val containerImage: Output<String>? = null,
    public val imageRegistryCredential: Output<ImageRegistryCredentialArgs>? = null,
    public val languageFramework: Output<String>? = null,
    public val server: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.CustomContainerArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.inputs.CustomContainerArgs =
        com.pulumi.azurenative.appplatform.inputs.CustomContainerArgs.builder()
            .args(args?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .command(command?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .containerImage(containerImage?.applyValue({ args0 -> args0 }))
            .imageRegistryCredential(
                imageRegistryCredential?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .languageFramework(languageFramework?.applyValue({ args0 -> args0 }))
            .server(server?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CustomContainerArgs].
 */
@PulumiTagMarker
public class CustomContainerArgsBuilder internal constructor() {
    private var args: Output<List<String>>? = null

    private var command: Output<List<String>>? = null

    private var containerImage: Output<String>? = null

    private var imageRegistryCredential: Output<ImageRegistryCredentialArgs>? = null

    private var languageFramework: Output<String>? = null

    private var server: Output<String>? = null

    /**
     * @param value Arguments to the entrypoint. The docker image's CMD is used if this is not provided.
     */
    @JvmName("khpxmesvrurioylv")
    public suspend fun args(`value`: Output<List<String>>) {
        this.args = value
    }

    @JvmName("rdjftrungirvnece")
    public suspend fun args(vararg values: Output<String>) {
        this.args = Output.all(values.asList())
    }

    /**
     * @param values Arguments to the entrypoint. The docker image's CMD is used if this is not provided.
     */
    @JvmName("tqstmsmhpetrwyds")
    public suspend fun args(values: List<Output<String>>) {
        this.args = Output.all(values)
    }

    /**
     * @param value Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided.
     */
    @JvmName("fqubqcflmqxnabgx")
    public suspend fun command(`value`: Output<List<String>>) {
        this.command = value
    }

    @JvmName("pixhnhngcxwrgory")
    public suspend fun command(vararg values: Output<String>) {
        this.command = Output.all(values.asList())
    }

    /**
     * @param values Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided.
     */
    @JvmName("rveutxmuuiufmpgu")
    public suspend fun command(values: List<Output<String>>) {
        this.command = Output.all(values)
    }

    /**
     * @param value Container image of the custom container. This should be in the form of <repository>:<tag> without the server name of the registry
     */
    @JvmName("ywywtgfyfyjmnoos")
    public suspend fun containerImage(`value`: Output<String>) {
        this.containerImage = value
    }

    /**
     * @param value Credential of the image registry
     */
    @JvmName("pdlglmqcsgfjyoas")
    public suspend fun imageRegistryCredential(`value`: Output<ImageRegistryCredentialArgs>) {
        this.imageRegistryCredential = value
    }

    /**
     * @param value Language framework of the container image uploaded
     */
    @JvmName("yucxnqojeifmddff")
    public suspend fun languageFramework(`value`: Output<String>) {
        this.languageFramework = value
    }

    /**
     * @param value The name of the registry that contains the container image
     */
    @JvmName("pvmujkmishunvkkv")
    public suspend fun server(`value`: Output<String>) {
        this.server = value
    }

    /**
     * @param value Arguments to the entrypoint. The docker image's CMD is used if this is not provided.
     */
    @JvmName("gubwfscychybmwuy")
    public suspend fun args(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.args = mapped
    }

    /**
     * @param values Arguments to the entrypoint. The docker image's CMD is used if this is not provided.
     */
    @JvmName("ibdlxkadncrpmgrn")
    public suspend fun args(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.args = mapped
    }

    /**
     * @param value Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided.
     */
    @JvmName("bdbbkgdvbvqwdgru")
    public suspend fun command(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.command = mapped
    }

    /**
     * @param values Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided.
     */
    @JvmName("akacfghptdpxdomj")
    public suspend fun command(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.command = mapped
    }

    /**
     * @param value Container image of the custom container. This should be in the form of <repository>:<tag> without the server name of the registry
     */
    @JvmName("gukflojtcckfwgpy")
    public suspend fun containerImage(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerImage = mapped
    }

    /**
     * @param value Credential of the image registry
     */
    @JvmName("wosbcbcxpuihqvja")
    public suspend fun imageRegistryCredential(`value`: ImageRegistryCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageRegistryCredential = mapped
    }

    /**
     * @param argument Credential of the image registry
     */
    @JvmName("mgeoajktjmlkwyrx")
    public suspend
    fun imageRegistryCredential(argument: suspend ImageRegistryCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = ImageRegistryCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.imageRegistryCredential = mapped
    }

    /**
     * @param value Language framework of the container image uploaded
     */
    @JvmName("raiejginurrgaoru")
    public suspend fun languageFramework(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.languageFramework = mapped
    }

    /**
     * @param value The name of the registry that contains the container image
     */
    @JvmName("kdirfyobayelkndq")
    public suspend fun server(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.server = mapped
    }

    internal fun build(): CustomContainerArgs = CustomContainerArgs(
        args = args,
        command = command,
        containerImage = containerImage,
        imageRegistryCredential = imageRegistryCredential,
        languageFramework = languageFramework,
        server = server,
    )
}
